@@ -14,6 +14,10 @@ __doc__ = r"""
 if __name__ == "__main__":
 
     def alt():
+        """
+
+        :return:
+        """
         import tensorflow as tf
         import numpy
 
@@ -42,6 +46,10 @@ if __name__ == "__main__":
                 self._summary_writer = summary_writer
 
             def end(self, session):
+                """
+
+                :param session:
+                """
                 cm = (
                     tf.get_default_graph()
                     .get_tensor_by_name(self.confusion_matrix_tensor_name + ":0")
@@ -139,14 +147,17 @@ if __name__ == "__main__":
                 return fig
 
     def asda():
+        """
 
+        :return:
+        """
         import io
         import itertools
         from packaging import version
 
         import tensorflow as tf
 
-        import matplotlib.pyplot as plt
+        from matplotlib import pyplot
         import numpy
 
         test_pred_raw = []
@@ -160,10 +171,10 @@ if __name__ == "__main__":
             returns it. The supplied figure is closed and inaccessible after this call."""
             # Save the plot to a PNG in memory.
             buf = io.BytesIO()
-            plt.savefig(buf, format="png")
+            pyplot.savefig(buf, format="png")
             # Closing the figure prevents it from being displayed directly inside
             # the notebook.
-            plt.close(figure)
+            pyplot.close(figure)
             buf.seek(0)
             # Convert PNG buffer to TF image
             image = tf.image.decode_png(buf.getvalue(), channels=4)
@@ -174,14 +185,14 @@ if __name__ == "__main__":
         def image_grid():
             """Return a 5x5 grid of the MNIST images as a matplotlib figure."""
             # Create a figure to contain the plot.
-            figure = plt.figure(figsize=(10, 10))
+            figure = pyplot.figure(figsize=(10, 10))
             for i in range(25):
                 # Start next subplot.
-                plt.subplot(5, 5, i + 1, title=class_names[train_labels[i]])
-                plt.xticks([])
-                plt.yticks([])
-                plt.grid(False)
-                plt.imshow(train_images[i], cmap=plt.cm.binary)
+                pyplot.subplot(5, 5, i + 1, title=class_names[train_labels[i]])
+                pyplot.xticks([])
+                pyplot.yticks([])
+                pyplot.grid(False)
+                pyplot.imshow(train_images[i], cmap=pyplot.cm.binary)
 
             return figure
 
@@ -193,13 +204,13 @@ if __name__ == "__main__":
               cm (array, shape = [n, n]): a confusion matrix of integer classes
               class_names (array, shape = [n]): String names of the integer classes
             """
-            figure = plt.figure(figsize=(8, 8))
-            plt.imshow(cm, interpolation="nearest", cmap=plt.cm.Blues)
-            plt.title("Confusion matrix")
-            plt.colorbar()
+            figure = pyplot.figure(figsize=(8, 8))
+            pyplot.imshow(cm, interpolation="nearest", cmap=pyplot.cm.Blues)
+            pyplot.title("Confusion matrix")
+            pyplot.colorbar()
             tick_marks = numpy.arange(len(class_names))
-            plt.xticks(tick_marks, class_names, rotation=45)
-            plt.yticks(tick_marks, class_names)
+            pyplot.xticks(tick_marks, class_names, rotation=45)
+            pyplot.yticks(tick_marks, class_names)
 
             # Compute the labels from the normalized confusion matrix.
             labels = numpy.around(
@@ -210,11 +221,13 @@ if __name__ == "__main__":
             threshold = cm.max() / 2.0
             for i, j in itertools.product(range(cm.shape[0]), range(cm.shape[1])):
                 color = "white" if cm[i, j] > threshold else "black"
-                plt.text(j, i, labels[i, j], horizontalalignment="center", color=color)
+                pyplot.text(
+                    j, i, labels[i, j], horizontalalignment="center", color=color
+                )
 
-            plt.tight_layout()
-            plt.ylabel("True label")
-            plt.xlabel("Predicted label")
+            pyplot.tight_layout()
+            pyplot.ylabel("True label")
+            pyplot.xlabel("Predicted label")
             return figure
 
         """
