@@ -31,8 +31,10 @@ def cross_validation_generator(
 
 if __name__ == "__main__":
 
-    def asdasidoj():
-        """ """
+    def asdasidoj() -> None:
+        """
+        :rtype: None
+        """
         X = to_tensor([torch.diag(torch.arange(i, i + 2)) for i in range(200)])
         x_train = TensorDataset(X[:100])
         x_val = TensorDataset(X[100:])
