@@ -24,16 +24,9 @@ def pad2d_hw_shape(
     double(h,w)
     single(all)
 
+      :param pad_size:
     :param h_w:
     :type h_w:
-    :param kernel_size:
-    :type kernel_size:
-    :param stride:
-    :type stride:
-    :param pad:
-    :type pad:
-    :param dilation:
-    :type dilation:
     :return:
     :rtype:"""
     h_w = replicate(h_w)
